@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -49,7 +49,7 @@
 
 /* Comment this if you want to build without any C library requirements */
 #define HAVE_LIBC 1
-#if HAVE_LIBC
+#ifdef HAVE_LIBC
 
 /* Useful headers */
 #define STDC_HEADERS 1
@@ -190,7 +190,10 @@
 #define HAVE_FOPEN64 1
 #define HAVE_FSEEKO 1
 #define HAVE_FSEEKO64 1
+#define HAVE_MEMFD_CREATE 1
+#define HAVE_POSIX_FALLOCATE 1
 #define HAVE_SIGACTION 1
+#define HAVE_SIGTIMEDWAIT 1
 #define HAVE_SA_SIGACTION 1
 #define HAVE_SETJMP 1
 #define HAVE_NANOSLEEP 1
@@ -200,6 +203,7 @@
 /* #undef HAVE_GETPAGESIZE */
 #define HAVE_MPROTECT 1
 #define HAVE_ICONV 1
+/* #undef SDL_USE_LIBICONV */
 #define HAVE_PTHREAD_SETNAME_NP 1
 /* #undef HAVE_PTHREAD_SET_NAME_NP */
 #define HAVE_SEM_TIMEDWAIT 1
@@ -223,7 +227,7 @@
 #define HAVE_INOTIFY_INIT 1
 #define HAVE_INOTIFY_INIT1 1
 #define HAVE_INOTIFY 1
-#define HAVE_LIBUSB 1
+/* #undef HAVE_LIBUSB */
 #define HAVE_O_CLOEXEC 1
 
 /* Apple platforms might be building universal binaries, where Intel builds
@@ -240,7 +244,7 @@
 
 #define HAVE_LIBUDEV_H 1
 #define HAVE_LIBSAMPLERATE_H 1
-#define HAVE_LIBDECOR_H  1
+#define HAVE_LIBDECOR_H 1
 
 /* #undef HAVE_D3D_H */
 /* #undef HAVE_D3D11_H */
@@ -259,8 +263,7 @@
 /* #undef HAVE_ROAPI_H */
 /* #undef HAVE_SHELLSCALINGAPI_H */
 
-/* #undef HAVE_XINPUT_GAMEPAD_EX */
-/* #undef HAVE_XINPUT_STATE_EX */
+/* #undef USE_POSIX_SPAWN */
 
 /* SDL internal assertion support */
 #if 0
@@ -315,7 +318,7 @@
 #define SDL_AUDIO_DRIVER_PIPEWIRE 1
 #define SDL_AUDIO_DRIVER_PIPEWIRE_DYNAMIC "libpipewire-0.3.so.0"
 #define SDL_AUDIO_DRIVER_PULSEAUDIO 1
-#define SDL_AUDIO_DRIVER_PULSEAUDIO_DYNAMIC "libpulse-simple.so.0"
+#define SDL_AUDIO_DRIVER_PULSEAUDIO_DYNAMIC "libpulse.so.0"
 /* #undef SDL_AUDIO_DRIVER_QSA */
 /* #undef SDL_AUDIO_DRIVER_SNDIO */
 /* #undef SDL_AUDIO_DRIVER_SNDIO_DYNAMIC */
@@ -359,7 +362,7 @@
 /* #undef SDL_HAPTIC_DINPUT */
 /* #undef SDL_HAPTIC_XINPUT */
 /* #undef SDL_HAPTIC_ANDROID */
-#define SDL_LIBUSB_DYNAMIC "libusb-1.0.so.0"
+/* #undef SDL_LIBUSB_DYNAMIC */
 #define SDL_UDEV_DYNAMIC "libudev.so.1"
 
 /* Enable various sensor drivers */
@@ -525,7 +528,7 @@
 /* #undef SDL_ARM_NEON_BLITTERS */
 
 /* Whether SDL_DYNAMIC_API needs dlopen */
-#define DYNAPI_NEEDS_DLOPEN  1
+#define DYNAPI_NEEDS_DLOPEN 1
 
 /* Enable dynamic libsamplerate support */
 #define SDL_LIBSAMPLERATE_DYNAMIC "libsamplerate.so.0"
@@ -541,7 +544,7 @@
 /* #undef SDL_VIDEO_VITA_PVR */
 /* #undef SDL_VIDEO_VITA_PVR_OGL */
 
-/* #undef SDL_HAVE_LIBDECOR_GET_MIN_MAX */
+#define SDL_HAVE_LIBDECOR_GET_MIN_MAX 1
 
 #if !defined(HAVE_STDINT_H) && !defined(_STDINT_H_)
 /* Most everything except Visual Studio 2008 and earlier has stdint.h now */
